==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>新規図面へのデフォルト</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>寸法設定</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>寸法</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Scientific</source>
        <translation>科学</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>小数</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>エンジニアリング</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>建築</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>分数</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Decimal Degrees</source>
        <translation>小数角度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>度/分/秒</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>グラード</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>ラジアン</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>測量</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>Unit / Format</source>
        <translation>ユニット/フォーマット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>寸法ラベルを’建築’または’エンジニアリング’フォーマットで表示するには、図面単位は’インチ’でなければなりません。フォーマットは’小数’に変更されました。</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>比率を維持</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>テキスト高さ:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>延長線のオフセット:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>延長線の拡張:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>寸法線のギャップ:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>矢印のサイズ:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>矢印のスタイル</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>矢印</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>建築チェック</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Label Format</source>
        <translation>ラベルフォーマット</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>線形寸法</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;F フォーマット:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>&amp;r 正確さ:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>末尾のゼロを表示</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>角度寸法</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>&amp;o フォーマット:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>&amp;c 正確さ:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>新規図面へのデフォルト</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>寸法設定</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>寸法</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scientific</source>
        <translation>科学</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>小数</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>エンジニアリング</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>建築</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>分数</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>小数角度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>度/分/秒</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>グラード</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>ラジアン</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>測量</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>Unit / Format</source>
        <translation>ユニット/フォーマット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>寸法ラベルを’建築’または’エンジニアリング’フォーマットで表示するには、図面単位は’インチ’でなければなりません。フォーマットは’小数’に変更されました。</translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="vanished">寸法ラベルを’建築’または’エンジニアリング’フォーマットで表示するには、図面単位は’インチ’でなければなりません。フォーマットは’小数’に変更されました。</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>比率を維持</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>テキスト高さ:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>延長線のオフセット:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>延長線の拡張:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>寸法線のギャップ:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>矢印のサイズ:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>倍率サイズ:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>矢印のスタイル</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>矢印</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>建築チェック</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>フォント</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>フォント:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Label Format</source>
        <translation>ラベルフォーマット</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>線形寸法</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;F フォーマット:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>&amp;r 正確さ:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>末尾のゼロを表示</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>角度寸法</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>&amp;o フォーマット:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>&amp;c 正確さ:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
</context>
</TS>
